Documentation
¶
Index ¶
- func IsGbProject(projectPath string) bool
- func ParseAppDescriptor(appJson string) (*config.FlogoAppDescriptor, error)
- type FlogoProject
- func (e *FlogoProject) Build() error
- func (e *FlogoProject) Create(createBin bool, vendorDir string) error
- func (e *FlogoProject) GetAppDir() string
- func (e *FlogoProject) GetBinDir() string
- func (e *FlogoProject) GetDockerBuild() bool
- func (e *FlogoProject) GetRootDir() string
- func (e *FlogoProject) GetSourceDir() string
- func (e *FlogoProject) GetVendorDir() string
- func (e *FlogoProject) GetVendorSrcDir() string
- func (e *FlogoProject) Init(rootDir string) error
- func (e *FlogoProject) InstallDependency(depPath string, version string) error
- func (e *FlogoProject) Open() error
- func (e *FlogoProject) SetDockerBuild()
- func (e *FlogoProject) UninstallDependency(depPath string) error
- type Gb
- func (e *Gb) Build() error
- func (e *Gb) Init(createBin bool)
- func (e *Gb) Installed() bool
- func (e *Gb) NewBinFilePath(fileName string) string
- func (e *Gb) VendorDelete(depPath string) error
- func (e *Gb) VendorDeleteSilent(depPath string) error
- func (e *Gb) VendorFetch(depPath string, version string) error
- type GbProject
- func (e *GbProject) Build() error
- func (e *GbProject) Create(createBin bool, vendorDir string) error
- func (e *GbProject) GetAppDir() string
- func (e *GbProject) GetBinDir() string
- func (e *GbProject) GetDockerBuild() bool
- func (e *GbProject) GetRootDir() string
- func (e *GbProject) GetSourceDir() string
- func (e *GbProject) GetVendorDir() string
- func (e *GbProject) GetVendorSrcDir() string
- func (e *GbProject) Init(basePath string) error
- func (e *GbProject) InstallDependency(depPath string, version string) error
- func (e *GbProject) Open() error
- func (e *GbProject) SetDockerBuild()
- func (e *GbProject) UninstallDependency(depPath string) error
- type Project
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsGbProject ¶
func ParseAppDescriptor ¶
func ParseAppDescriptor(appJson string) (*config.FlogoAppDescriptor, error)
ParseAppDescriptor parse the application descriptor
Types ¶
type FlogoProject ¶
type FlogoProject struct {
BinDir string
RootDir string
SourceDir string
VendorDir string
VendorSrcDir string
CodeSourcePath string
AppDir string
FileDescriptorPath string
DockerBuild bool
}
func (*FlogoProject) Build ¶
func (e *FlogoProject) Build() error
func (*FlogoProject) Create ¶
func (e *FlogoProject) Create(createBin bool, vendorDir string) error
Create creates directories for the project
func (*FlogoProject) GetAppDir ¶
func (e *FlogoProject) GetAppDir() string
GetAppDir returns the directory of the app
func (*FlogoProject) GetBinDir ¶
func (e *FlogoProject) GetBinDir() string
func (*FlogoProject) GetDockerBuild ¶
func (e *FlogoProject) GetDockerBuild() bool
func (*FlogoProject) GetRootDir ¶
func (e *FlogoProject) GetRootDir() string
func (*FlogoProject) GetSourceDir ¶
func (e *FlogoProject) GetSourceDir() string
func (*FlogoProject) GetVendorDir ¶
func (e *FlogoProject) GetVendorDir() string
func (*FlogoProject) GetVendorSrcDir ¶
func (e *FlogoProject) GetVendorSrcDir() string
func (*FlogoProject) Init ¶
func (e *FlogoProject) Init(rootDir string) error
func (*FlogoProject) InstallDependency ¶
func (e *FlogoProject) InstallDependency(depPath string, version string) error
Deprecated, dependency managements responsibility
func (*FlogoProject) Open ¶
func (e *FlogoProject) Open() error
Open the project directory and validate its structure
func (*FlogoProject) SetDockerBuild ¶
func (e *FlogoProject) SetDockerBuild()
func (*FlogoProject) UninstallDependency ¶
func (e *FlogoProject) UninstallDependency(depPath string) error
Deprecated, dependency managements responsibility
type Gb ¶
Gb structure that contains gb project paths
func (*Gb) NewBinFilePath ¶
NewBinFilepath.Join creates a new file path.Join in the bin directory
func (*Gb) VendorDelete ¶
VendorDelete performs a 'gb vendor delete'
func (*Gb) VendorDeleteSilent ¶
VendorDeleteSilent performs a 'gb vendor delete' silently
type GbProject ¶
type GbProject struct {
BinDir string
RootDir string
SourceDir string
VendorDir string
VendorSrcDir string
CodeSourcePath string
DockerBuild bool
}
func (*GbProject) GetDockerBuild ¶
func (*GbProject) GetRootDir ¶
func (*GbProject) GetSourceDir ¶
func (*GbProject) GetVendorDir ¶
func (*GbProject) GetVendorSrcDir ¶
func (*GbProject) InstallDependency ¶
func (*GbProject) SetDockerBuild ¶
func (e *GbProject) SetDockerBuild()
func (*GbProject) UninstallDependency ¶
type Project ¶
type Project interface {
// Init initializes the project settings an validates it requirements
Init(path string) error
// Create the project directory and its structure, optional existing vendor dir to copy
Create(withBinDir bool, vendorDir string) error
// Open the project directory and validate its structure
Open() error
// Sets whether this is a docker build or not
SetDockerBuild()
// GetDockerBuild returns whether this is a docker build or not
GetDockerBuild() bool
// GetBinDir get the bin directory of the project
GetBinDir() string
// GetRootDir get the root directory of the project
GetRootDir() string
// GetSourceDir get the source directory of the project
GetSourceDir() string
// GetVendorDir get the vendor directory of the project
GetVendorDir() string
// GetVendorSrcDir get the vendor source directory of the project
GetVendorSrcDir() string
// GetAppDir get the app directory of the project
GetAppDir() string
// Install a go dependency
InstallDependency(path string, version string) error
// Uninstall a go dependency
UninstallDependency(path string) error
// Build the project
Build() error
}
func NewFlogoProject ¶
func NewFlogoProject() Project
func NewGbProjectEnv ¶
func NewGbProjectEnv() Project
Click to show internal directories.
Click to hide internal directories.